==> kdepim-3.2.3.tar.bz2: kdepim-3.2.3/kmail/bodypartformatter.h <==
/*  -*- c++ -*-
    bodypartformatter.h

    This file is part of KMail, the KDE mail client.
    Copyright (c) 2003 Marc Mutz <mutz@kde.org>

    KMail is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License, version 2, as
    published by the Free Software Foundation.

    KMail is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KMAIL_BODYPARTFORMATTER_H__
#define __KMAIL_BODYPARTFORAMTTER_H__

class partNode;

namespace KMail {

  class ObjectTreeParser;
  class ProcessResult;

  class BodyPartFormatter {
    const BodyPartFormatter & operator=( const BodyPartFormatter & );
    BodyPartFormatter( const BodyPartFormatter & );
  protected:
    BodyPartFormatter() {}
  public:
    virtual ~BodyPartFormatter() {}

    virtual bool process( ObjectTreeParser *, partNode *, ProcessResult & ) const = 0;

    static const BodyPartFormatter * createFor( int type, int subtype );
    static const BodyPartFormatter * createFor( const char * type, const char * subtype );
  };

} // namespace KMail

#endif // __KMAIL_BODYPARTFORMATTER_H__

==> kdepim-3.3.2.tar.bz2: kdepim-3.3.2/kmail/bodypartformatter.h <==
/*  -*- c++ -*-
    bodypartformatter.h

    This file is part of KMail, the KDE mail client.
    Copyright (c) 2003 Marc Mutz <mutz@kde.org>

    KMail is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License, version 2, as
    published by the Free Software Foundation.

    KMail is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KMAIL_BODYPARTFORMATTER_H__
#define __KMAIL_BODYPARTFORMATTER_H__

class partNode;

namespace KMail {

  class ObjectTreeParser;
  class ProcessResult;

  class BodyPartFormatter {
    const BodyPartFormatter & operator=( const BodyPartFormatter & );
    BodyPartFormatter( const BodyPartFormatter & );
  protected:
    BodyPartFormatter() {}
  public:
    virtual ~BodyPartFormatter() {}

    virtual bool process( ObjectTreeParser *, partNode *, ProcessResult & ) const = 0;

    static const BodyPartFormatter * createFor( int type, int subtype );
    static const BodyPartFormatter * createFor( const char * type, const char * subtype );
  };

} // namespace KMail

#endif // __KMAIL_BODYPARTFORMATTER_H__
